#!/bin/sh
##
## buildstatic.sh, written by Sergey B Kirpichev <skirpichev@gmail.com>
##
## Build all static html reports from AWStats data (Debian specific)
##

set -e

DEFAULT=/etc/default/awstats
AWSTATS=/usr/lib/cgi-bin/awstats.pl
BUILDSTATICPAGES=/usr/share/awstats/tools/awstats_buildstaticpages.pl

# Set defaults.
AWSTATS_NICE=10
AWSTATS_ENABLE_BUILDSTATICPAGES="no"
AWSTATS_LANG="en"

[ -f $AWSTATS -a -f $BUILDSTATICPAGES ] || exit 1
[ -r "$DEFAULT" ] && . "$DEFAULT"

if [ "$AWSTATS_ENABLE_BUILDSTATICPAGES" != "yes" ]; then
  exit 0
fi

Y=`date +%Y`
m=`date +%m`

cd /etc/awstats

TMPFILE=`mktemp /tmp/awstats.XXXXXXXXXX`
for c in awstats.*.conf; do
  c=${c#awstats.} # remove prefix
  c=${c%.conf}    # remove suffix
  mkdir -p /var/cache/awstats/$c/$Y/$m/
  if ! nice -n $AWSTATS_NICE $BUILDSTATICPAGES \
	-config=$c \
	-year=$Y \
	-month=$m \
	-lang=$AWSTATS_LANG \
	-staticlinksext=${AWSTATS_LANG}.html \
	-awstatsprog=$AWSTATS \
	-dir=/var/cache/awstats/$c/$Y/$m/ >$TMPFILE 2>&1
  then
    # an error occurred
    cat $TMPFILE >&2
  fi
done
rm -f $TMPFILE
